ZoomOptions class

Basic Zoom Options required for plugin (WEB, iOS, Android)

Constructors

ZoomOptions({required String? domain, String? appKey, String? appSecret, String? language = "en-US", bool? showMeetingHeader = true, bool? disableInvite = false, bool? disableCallOut = false, bool? disableRecord = false, bool? disableJoinAudio = false, bool? audioPanelAlwaysOpen = false, bool? isSupportAV = true, bool? isSupportChat = true, bool? isSupportQA = true, bool? isSupportCC = true, bool? isSupportPolling = true, bool? isSupportBreakout = true, bool? screenShare = true, String? rwcBackup = '', bool? videoDrag = true, String? sharingMode = 'both', bool? videoHeader = true, bool? isLockBottom = true, bool? isSupportNonverbal = true, bool? isShowJoiningErrorDialog = true, bool? disablePreview = false, bool? disableCORP = true, String? inviteUrlFormat = '', bool? disableVOIP = false, bool? disableReport = false, List<String>? meetingInfo = const ['topic', 'host', 'mn', 'pwd', 'telPwd', 'invite', 'participant', 'dc', 'enctype', 'report']})
--Meeting Info for web

Properties

appKey ↔ String?
Domain For Zoom Web
getter/setter pair
appSecret ↔ String?
--JWT key for web / SDK key for iOS / Android
getter/setter pair
audioPanelAlwaysOpen ↔ bool?
--Disable Join Audio for web
getter/setter pair
disableCallOut ↔ bool?
--Disable Invite Option for web
getter/setter pair
disableCORP ↔ bool?
--Disable Preview for web
getter/setter pair
disableInvite ↔ bool?
--Meeting Header for web
getter/setter pair
disableJoinAudio ↔ bool?
--Disable Record Option for web
getter/setter pair
disablePreview ↔ bool?
--Error Dialog Visibility for web
getter/setter pair
disableRecord ↔ bool?
--Disable CallOut Option for web
getter/setter pair
disableReport ↔ bool?
--Disable VOIP for web
getter/setter pair
disableVOIP ↔ bool?
--Invite Url Format for web
getter/setter pair
domain ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
inviteUrlFormat ↔ String?
--Disable Crop for web
getter/setter pair
isLockBottom ↔ bool?
--Video Header for web
getter/setter pair
isShowJoiningErrorDialog ↔ bool?
--Nonverbal Support for web
getter/setter pair
isSupportAV ↔ bool?
-- Allow Pannel Always Open for web
getter/setter pair
isSupportBreakout ↔ bool?
--Polling Support for web
getter/setter pair
isSupportCC ↔ bool?
--QA Support for web
getter/setter pair
isSupportChat ↔ bool?
--AV Support for web
getter/setter pair
isSupportNonverbal ↔ bool?
--Lock Bottom Support for web
getter/setter pair
isSupportPolling ↔ bool?
--CC Support for web
getter/setter pair
isSupportQA ↔ bool?
--Chat Suppport for web
getter/setter pair
language ↔ String?
--JWT secret for web / SDK secret for iOS / Android
getter/setter pair
meetingInfo ↔ List<String>?
--Disable Report for web
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
rwcBackup ↔ String?
--Screen Sharing Option for web
getter/setter pair
screenShare ↔ bool?
-- Breakout Support for web
getter/setter pair
sharingMode ↔ String?
-- Drag Video Option for web
getter/setter pair
showMeetingHeader ↔ bool?
--Language for web
getter/setter pair
videoDrag ↔ bool?
--RWC Backup Option for web
getter/setter pair
videoHeader ↔ bool?
--Sharing Mode for web
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited