ZoomView class

Inheritance

Constructors

ZoomView()

Properties

channel → MethodChannel
final
eventChannel → EventChannel
The event channel used to interact with the native platform.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

initZoom(ZoomOptions options) → Future<List>
The event channel used to interact with the native platform init function
override
joinMeeting(ZoomMeetingOptions options) → Future<bool>
The event channel used to interact with the native platform joinMeeting function
override
meetinDetails() → Future<List>
The event channel used to interact with the native platform meetinDetails(iOS & Android) function
override
meetingStatus(String meetingId) → Future<List>
The event channel used to interact with the native platform meetingStatus function
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onMeetingStatus() → Stream
The event channel used to interact with the native platform onMeetingStatus(iOS & Android) function
override
startMeeting(ZoomMeetingOptions options) → Future<List>
The event channel used to interact with the native platform startMeeting(login on iOS & Android) function
override
startMeetingNormal(ZoomMeetingOptions options) → Future<List>
The event channel used to interact with the native platform startMeetingNormal function
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited